export const colorLegend = (selection, props) => {
const {                
    scoreScale,
    upper,
    lower,
    name,
    string
  } = props;
  
  let svgLegend = d3.select(props.name);
  svgLegend.html("");
  var defs = svgLegend.append("defs");

  // append a linearGradient element to the defs and give it a unique id
  const id = "linear-gradient".concat(props.lower, props.upper);

  var linearGradient = defs.append("linearGradient").attr("id", id);

  // horizontal gradient
  linearGradient
    .attr("x1", "0%")
    .attr("y1", "0%")
    .attr("x2", "100%")
    .attr("y2", "0%");

  // append multiple color stops by using D3's data/enter step

  linearGradient
    .selectAll("stop")
    .data(props.scale.domain())
    .enter()
    .append("stop")
    .attr("offset", function(d) {
      return d + "%";
    })
    .attr("stop-color", function(d) {
      return props.scale(d);
    });

  // append title
  svgLegend
    .append("text")
    .attr("class", "legendTitle")
    .attr("x", 0)
    .attr("y", 20)
    .style("text-anchor", "left")
    .text(props.string);

  // draw the rectangle and fill with gradient
  svgLegend
    .append("rect")
    .attr("x", 10)
    .attr("y", 30)
    .attr("width", 400)
    .attr("height", 15)
    .style("fill", `url(#${id})`);

  //create tick marks
  var xLeg = d3
    .scaleLinear()
    .domain([props.lower, props.upper])
    .range([10, 400]);

  var axisLeg = d3.axisBottom(xLeg).tickValues(props.scale.domain());

  svgLegend
    .attr("class", "axis")
    .append("g")
    .attr("transform", "translate(0, 40)")
    .call(axisLeg);

}